@@ -17,6 +17,7 @@ import copy
 
 from keystoneauth1 import session
 import mock
+from oslo_utils import uuidutils
 
 import novaclient.api_versions
 import novaclient.client
@@ -34,10 +35,6 @@ class ClientTest(utils.TestCase):
         output = novaclient.client.get_client_class(2)
         self.assertEqual(output, novaclient.v2.client.Client)
 
-    def test_get_client_class_v1_1(self):
-        output = novaclient.client.get_client_class('1.1')
-        self.assertEqual(output, novaclient.v2.client.Client)
-
     def test_get_client_class_unknown(self):
         self.assertRaises(novaclient.exceptions.UnsupportedVersion,
                           novaclient.client.get_client_class, '0')
@@ -51,8 +48,7 @@ class ClientTest(utils.TestCase):
 
 class SessionClientTest(utils.TestCase):
 
-    @mock.patch.object(novaclient.client, '_log_request_id')
-    def test_timings(self, mock_log_request_id):
+    def test_timings(self):
         self.requests_mock.get('http://no.where')
 
         client = novaclient.client.SessionClient(session=session.Session())
@@ -75,25 +71,24 @@ class SessionClientTest(utils.TestCase):
         cs.reset_timings()
         self.assertEqual(0, len(cs.get_timings()))
 
-    @mock.patch.object(novaclient.client, '_log_request_id')
-    def test_log_request_id(self, mock_log_request_id):
+    def test_global_id(self):
+        global_id = "req-%s" % uuidutils.generate_uuid()
         self.requests_mock.get('http://no.where')
+
         client = novaclient.client.SessionClient(session=session.Session(),
-                                                 service_name='compute')
+                                                 global_request_id=global_id)
         client.request("http://no.where", 'GET')
-        mock_log_request_id.assert_called_once_with(client.logger, mock.ANY,
-                                                    'compute')
+        headers = self.requests_mock.last_request.headers
+        self.assertEqual(headers['X-OpenStack-Request-ID'], global_id)
 
 
 class ClientsUtilsTest(utils.TestCase):
 
     @mock.patch("novaclient.client._discover_via_entry_points")
-    @mock.patch("novaclient.client._discover_via_contrib_path")
     @mock.patch("novaclient.client._discover_via_python_path")
     @mock.patch("novaclient.extension.Extension")
     def test_discover_extensions_all(self, mock_extension,
                                      mock_discover_via_python_path,
-                                     mock_discover_via_contrib_path,
                                      mock_discover_via_entry_points):
         def make_gen(start, end):
             def f(*args, **kwargs):
@@ -102,36 +97,34 @@ class ClientsUtilsTest(utils.TestCase):
             return f
 
         mock_discover_via_python_path.side_effect = make_gen(0, 3)
-        mock_discover_via_contrib_path.side_effect = make_gen(3, 5)
-        mock_discover_via_entry_points.side_effect = make_gen(5, 6)
+        mock_discover_via_entry_points.side_effect = make_gen(3, 4)
 
         version = novaclient.api_versions.APIVersion("2.0")
 
         result = novaclient.client.discover_extensions(version)
 
-        self.assertEqual([mock.call("name-%s" % i, i) for i in range(0, 6)],
+        self.assertEqual([mock.call("name-%s" % i, i) for i in range(0, 4)],
                          mock_extension.call_args_list)
         mock_discover_via_python_path.assert_called_once_with()
-        mock_discover_via_contrib_path.assert_called_once_with(version)
         mock_discover_via_entry_points.assert_called_once_with()
-        self.assertEqual([mock_extension()] * 6, result)
+        self.assertEqual([mock_extension()] * 4, result)
 
+    @mock.patch('novaclient.client.warnings')
     @mock.patch("novaclient.client._discover_via_entry_points")
-    @mock.patch("novaclient.client._discover_via_contrib_path")
     @mock.patch("novaclient.client._discover_via_python_path")
     @mock.patch("novaclient.extension.Extension")
     def test_discover_extensions_only_contrib(
             self, mock_extension, mock_discover_via_python_path,
-            mock_discover_via_contrib_path, mock_discover_via_entry_points):
-        mock_discover_via_contrib_path.return_value = [("name", "module")]
+            mock_discover_via_entry_points, mock_warnings):
 
         version = novaclient.api_versions.APIVersion("2.0")
 
-        novaclient.client.discover_extensions(version, only_contrib=True)
-        mock_discover_via_contrib_path.assert_called_once_with(version)
+        self.assertEqual([], novaclient.client.discover_extensions(
+            version, only_contrib=True))
         self.assertFalse(mock_discover_via_python_path.called)
         self.assertFalse(mock_discover_via_entry_points.called)
-        mock_extension.assert_called_once_with("name", "module")
+        self.assertFalse(mock_extension.called)
+        self.assertTrue(mock_warnings.warn.called)
 
     @mock.patch("novaclient.client.warnings")
     def test__check_arguments(self, mock_warnings):
