@@ -155,7 +155,8 @@ class FlavorManager(base.ManagerWithFind):
     def delete(self, flavor):
         """Delete a specific flavor.
 
-        :param flavor: The ID of the :class:`Flavor` to get.
+        :param flavor: Instance of :class:`Flavor` to delete or ID of the
+                       flavor to delete.
         :returns: An instance of novaclient.base.TupleWithMeta
         """
         return self._delete("/flavors/%s" % base.getid(flavor))
@@ -184,11 +185,11 @@ class FlavorManager(base.ManagerWithFind):
         :param name: Descriptive name of the flavor
         :param ram: Memory in MB for the flavor
         :param vcpus: Number of VCPUs for the flavor
-        :param disk: Size of local disk in GB
+        :param disk: Size of local disk in GiB
         :param flavorid: ID for the flavor (optional). You can use the reserved
                          value ``"auto"`` to have Nova generate a UUID for the
                          flavor in cases where you cannot simply pass ``None``.
-        :param ephemeral: Ephemeral disk space in GB.
+        :param ephemeral: Ephemeral disk space in GiB.
         :param swap: Swap space in MB
         :param rxtx_factor: RX/TX factor
         :param is_public: Whether or not the flavor is public.
