@@ -27,7 +27,8 @@ class MigrationManager(base.ManagerWithFind):
     resource_class = Migration
 
     def _list_base(self, host=None, status=None, instance_uuid=None,
-                   marker=None, limit=None, changes_since=None):
+                   marker=None, limit=None, changes_since=None,
+                   changes_before=None):
         opts = {}
         if host:
             opts['host'] = host
@@ -41,6 +42,8 @@ class MigrationManager(base.ManagerWithFind):
             opts['limit'] = limit
         if changes_since:
             opts['changes-since'] = changes_since
+        if changes_before:
+            opts['changes-before'] = changes_before
 
         return self._list("/os-migrations", "migrations", filters=opts)
 
@@ -55,7 +58,7 @@ class MigrationManager(base.ManagerWithFind):
         return self._list_base(host=host, status=status,
                                instance_uuid=instance_uuid)
 
-    @api_versions.wraps("2.59")
+    @api_versions.wraps("2.59", "2.65")
     def list(self, host=None, status=None, instance_uuid=None,
              marker=None, limit=None, changes_since=None):
         """
@@ -67,11 +70,37 @@ class MigrationManager(base.ManagerWithFind):
         migrations list than that represented by this migration UUID
         (optional).
         :param limit: maximum number of migrations to return (optional).
-        :param changes_since: only return migrations updated after. The
-        provided time should be an ISO 8061 formatted time. ex
-        2016-03-04T06:27:59Z . (optional).
+        :param changes_since: only return migrations changed later or equal
+        to a certain point of time. The provided time should be an ISO 8061
+        formatted time. e.g. 2016-03-04T06:27:59Z . (optional).
         """
         return self._list_base(host=host, status=status,
                                instance_uuid=instance_uuid,
                                marker=marker, limit=limit,
                                changes_since=changes_since)
+
+    @api_versions.wraps("2.66")
+    def list(self, host=None, status=None, instance_uuid=None,
+             marker=None, limit=None, changes_since=None,
+             changes_before=None):
+        """
+        Get a list of migrations.
+        :param host: filter migrations by host name (optional).
+        :param status: filter migrations by status (optional).
+        :param instance_uuid: filter migrations by instance uuid (optional).
+        :param marker: Begin returning migrations that appear later in the
+        migrations list than that represented by this migration UUID
+        (optional).
+        :param limit: maximum number of migrations to return (optional).
+        :param changes_since: Only return migrations changed later or equal
+        to a certain point of time. The provided time should be an ISO 8061
+        formatted time. e.g. 2016-03-04T06:27:59Z . (optional).
+        :param changes_before: Only return migrations changed earlier or
+        equal to a certain point of time. The provided time should be an ISO
+        8061 formatted time. e.g. 2016-03-05T06:27:59Z . (optional).
+        """
+        return self._list_base(host=host, status=status,
+                               instance_uuid=instance_uuid,
+                               marker=marker, limit=limit,
+                               changes_since=changes_since,
+                               changes_before=changes_before)
